@@ -15,14 +15,15 @@
 #endif
 
 #ifdef CLUTTERPERL_GTK
-#include <clutter-gtk/clutter-gtk.h>
+#include <clutter-gtk/gtk-clutter-embed.h>
 #endif
 
 #include "clutterperl-autogen.h"
 
+G_BEGIN_DECLS
+
 const char *clutterperl_event_get_package (ClutterEvent *event);
 
-ClutterBoxChild *SvClutterBoxChild    (SV              *data);
-SV *             newSVClutterBoxChild (ClutterBoxChild *child);
+G_END_DECLS
 
 #endif /* _CLUTTER_PERL_H_ */
