@@ -88,7 +88,10 @@ sub ALPHA_NOTIFY {
     return unless scalar @actors;
 
     foreach my $actor (@actors) {
-        $actor->rotate_z($angle, $actor->get_x() - 100, $actor->get_y() - 100);
+        $actor->set_rotation('z-axis', $angle,
+                             $actor->get_x() - 20,
+                             $actor->get_y() - 20,
+                             0);
     }
 }
 
@@ -138,7 +141,13 @@ else {
 my $timeline = Clutter::Timeline->new(100, 26);
 $timeline->set(loop => TRUE);
 
-my $alpha = Clutter::Alpha->new($timeline, \&Clutter::Alpha::sine);
+my $alpha = Clutter::Alpha->new($timeline, sub {
+    my $alpha = shift;
+    my $timeline = $alpha->get_timeline();
+
+    return int($timeline->get_progress() * Clutter::Alpha->MAX_ALPHA);
+});
+
 my $o_behave = Clutter::Behaviour::Opacity->new($alpha, 0x33, 0xff);
 $o_behave->apply($group);
 
